diff src/memline.c @ 9:4102fb4ea781 v7.0002

updated for version 7.0002
author vimboss
date Sun, 20 Jun 2004 12:51:53 +0000
parents 3fc0f57ecb91
children 24d5189d3956
line wrap: on
line diff
--- a/src/memline.c
+++ b/src/memline.c
@@ -1518,7 +1518,7 @@ swapfile_info(fname)
 	    {
 		MSG_PUTS(_("         file name: "));
 		if (b0.b0_fname[0] == NUL)
-		    MSG_PUTS(_("[No File]"));
+		    MSG_PUTS(_("[No Name]"));
 		else
 		    msg_outtrans(b0.b0_fname);
 
@@ -3781,7 +3781,7 @@ findswapname(buf, dirp, old_fname)
 	 * Change the ".swp" extension to find another file that can be used.
 	 * First decrement the last char: ".swo", ".swn", etc.
 	 * If that still isn't enough decrement the last but one char: ".svz"
 	 * Can happen when editing many "No File" buffers.
 	 */
 	if (fname[n - 1] == 'a')	/* ".s?a" */
 	{
@@ -3781,7 +3781,7 @@ findswapname(buf, dirp, old_fname)
 	 * First decrement the last char: ".swo", ".swn", etc.
 	 * If that still isn't enough decrement the last but one char: ".svz"
-	 * Can happen when editing many "No File" buffers.
+	 * Can happen when editing many "No Name" buffers.
 	 */
 	if (fname[n - 1] == 'a')	/* ".s?a" */